@@ -1,11 +1,10 @@
 """Abstraction over the data storage for the application."""
 from __future__ import annotations
 
-from . import abc, filters, sqlalchemy, types
+from . import abc, filters, types
 
 __all__ = [
     "abc",
     "filters",
-    "sqlalchemy",
     "types",
 ]
