@@ -1,11 +1,8 @@
 """Application testing support."""
-
 from .controller_test import ControllerTest
-from .generic_mock_repository import GenericMockRepository
 from .modify_settings import modify_settings
 
 __all__ = (
     "ControllerTest",
-    "GenericMockRepository",
     "modify_settings",
 )
